import * as React$1 from 'react';
import React__default from 'react';
import { TextFieldVariants, FilledTextFieldProps, StandardTextFieldProps, OutlinedTextFieldProps } from '@mui/material';
import { MuiTelInputInfo } from 'mui-tel-input';

interface required {
    validator: "required";
}
interface matchRegexp {
    validator: "matchRegexp";
    regexp: RegExp | string;
}
interface isEmail {
    validator: "isEmail";
}
interface isEmpty {
    validator: "isEmpty";
}
interface trim {
    validator: "trim";
}
interface isNumber {
    validator: "isNumber";
}
interface isFloat {
    validator: "isFloat";
}
interface isPositive {
    validator: "isPositive";
}
interface maxNumber {
    validator: "maxNumber";
    max: number;
}
interface minNumber {
    validator: "minNumber";
    min: number;
}
interface maxFloat {
    validator: "maxFloat";
    max: number;
}
interface minFloat {
    validator: "minFloat";
    min: number;
}
interface isString {
    validator: "isString";
}
interface minStringLength {
    validator: "minStringLength";
    min: number;
}
interface maxStringLength {
    validator: "maxStringLength";
    max: number;
}
interface isFile {
    validator: "isFile";
}
interface maxFileSize {
    validator: "maxFileSize";
    max: number;
}
interface allowedExtensions {
    validator: "allowedExtensions";
    fileTypes: string;
}
type Validator = required | matchRegexp | isEmail | isEmpty | trim | isNumber | isFloat | isPositive | maxNumber | minNumber | maxFloat | minFloat | isString | minStringLength | maxStringLength | isFile | maxFileSize | allowedExtensions;

type MuiTextFieldProps<Variant extends TextFieldVariants = TextFieldVariants> = Variant extends "filled" ? FilledTextFieldProps : Variant extends "standard" ? StandardTextFieldProps : OutlinedTextFieldProps & ValidatorComponentProps;
interface ValidatorComponentProps {
    errorMessages?: string | string[];
    validators?: Validator[];
    value: any;
    validatorListener?: (value: boolean) => void;
    withRequiredValidator?: boolean;
    containerProps?: object;
    onChangeTel?: (value: string, info: MuiTelInputInfo) => void;
}
interface ValidatorComponentState {
    isValid?: boolean;
    value: any;
    errorMessages?: string | string[];
    validators?: Validator[];
}
interface ValidatorFormProps {
    onSubmit: () => void;
    instantValidate?: boolean;
    children?: React.ReactNode;
    onError?: (errors: any[]) => void;
    debounceTime?: number;
}

declare class ValidatorForm extends React$1.Component<ValidatorFormProps> {
    static getValidator: (value: any, validator: Validator) => boolean;
    childs: any[];
    errors: any[];
    instantValidate: boolean;
    debounceTime: number | undefined;
    getFormHelpers: () => {
        form: {
            attachToForm: (component: any) => void;
            debounceTime: number | undefined;
            detachFromForm: (component: any) => void;
            instantValidate: boolean | undefined;
        };
    };
    attachToForm: (component: any) => void;
    detachFromForm: (component: any) => void;
    submit: (event: React$1.FormEvent<HTMLFormElement>) => void;
    walk: (children: any[], dryRun?: boolean) => Promise<boolean>;
    checkInput: (input: any, dryRun?: boolean) => Promise<boolean>;
    validate: (input: any, includeRequired: boolean, dryRun?: boolean) => Promise<boolean>;
    find: (collection: any[], fn: (item: any) => boolean) => any;
    resetValidations: () => void;
    isFormValid: (dryRun?: boolean) => Promise<boolean>;
    render(): React$1.JSX.Element;
}

declare class ValidatorComponent extends React$1.Component<MuiTextFieldProps & ValidatorComponentProps, ValidatorComponentState> {
    renderValidatorComponent(): React$1.ReactNode;
    form: any;
    debounceTime: any;
    validateDebounced: {
        (value: any, includeRequired?: boolean | undefined, dryRun?: boolean | undefined): void;
        cancel: () => void;
    } | any;
    constructor(props: MuiTextFieldProps & ValidatorComponentProps);
    getSnapshotBeforeUpdate(nextProps: Readonly<MuiTextFieldProps & ValidatorComponentProps>, prevState: Readonly<ValidatorComponentState>): {
        value: any;
        validators: Validator[];
        errorMessages: string | string[];
    } | {
        value: any;
        validators?: undefined;
        errorMessages?: undefined;
    };
    instantValidate: boolean;
    invalid: number[];
    componentDidMount(): void;
    configure: () => void;
    shouldComponentUpdate(nextProps: MuiTextFieldProps, nextState: ValidatorComponentState): boolean;
    componentDidUpdate(prevProps: MuiTextFieldProps, prevState: ValidatorComponentState): void;
    componentWillUnmount(): void;
    getErrorMessage: () => string | boolean | string[];
    validate: (value: any, dryRun?: boolean) => Promise<boolean>;
    isValid: () => boolean;
    makeInvalid: () => void;
    makeValid: () => void;
    renderComponent: (form: ValidatorForm) => React$1.ReactNode;
    render(): React$1.JSX.Element;
}

declare class MuiSelect extends ValidatorComponent {
    renderValidatorComponent(): React$1.JSX.Element;
}

declare class MuiTextField extends ValidatorComponent {
    renderValidatorComponent(): React__default.JSX.Element;
}

declare class MuiTelInputDefault extends ValidatorComponent {
    renderValidatorComponent(): React__default.JSX.Element;
}

export { ValidatorComponent as MuiComponent, ValidatorForm as MuiForm, MuiTelInputDefault as MuiPhoneNumber, MuiSelect, MuiTextField, Validator as MuiValidator };
